@@ -1,6 +1,6 @@
 package Datahub::Factory;
 
-our $VERSION = '0.9';
+our $VERSION = '1.0';
 
 use Datahub::Factory::Sane;
 
@@ -18,6 +18,7 @@ use Sub::Exporter -setup => {
         store            => curry_method,
         exporter         => curry_method,
         pipeline         => curry_method,
+        module           => curry_method,
     ],
     collectors => {'-load' => \'_import_load', ':load' => \'_import_load'},
 };
@@ -79,6 +80,11 @@ sub pipeline {
     return $class->_env->pipeline(@_);
 }
 
+sub module {
+    my $class = shift;
+    return $class->_env->module(@_);
+}
+
 1;
 __END__
 
